@@ -3,7 +3,7 @@ use warnings;
 
 package Pod::Weaver::Plugin::Include;
 
-our $VERSION = 'v0.1.4';
+our $VERSION = 'v0.1.5';
 
 # ABSTRACT: Support for including sections of Pod from other files
 
@@ -101,9 +101,9 @@ package Pod::Weaver::Plugin::Include::Transformer {
     sub _add_child {
         my $this = shift;
 
-        $this->logger->log( "Adding a child:",
+        $this->logger->log_debug( "Adding a child:",
             map { $_->as_pod_string } ( ref( $_[0] ) ? $_[0] : [ $_[0] ] ) );
-        $this->logger->log("Skipping the child") if $this->_skipContent;
+        $this->logger->log_debug("Skipping the child") if $this->_skipContent;
 
         return if $this->_skipContent;
 
@@ -134,15 +134,15 @@ package Pod::Weaver::Plugin::Include::Transformer {
         my $this = shift;
         my $para = shift;
 
-        $this->logger->log( "_resetSkipIf for",
+        $this->logger->log_debug( "_resetSkipIf for",
             ref($para), ( $para->can('command') ? $para->command : "" ) );
 
         if ( $this->_skipContent ) {
             $this->_skipContent(0)
               if $para->isa('Pod::Elemental::Element::Pod5::Command')
               && $para->command eq 'tmpl';
-            $this->logger->log( "PARA IS:", ref($para) );
-            $this->logger->log( "Skipping content",
+            $this->logger->log_debug( "PARA IS:", ref($para) );
+            $this->logger->log_debug( "Skipping content",
                 ( $this->_skipContent ? "on" : "off" ) );
         }
     }
@@ -286,7 +286,7 @@ Pod::Weaver::Plugin::Include - Support for including sections of Pod from other
 
 =head1 VERSION
 
-version v0.1.4
+version v0.1.5
 
 =head1 SYNOPSIS
 
